==> mx-bootrepair_23.3.01.tar.xz: mx-bootrepair-23.3.01/translations/mx-boot-repair_sq.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="sq">
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../mainwindow.ui" line="20"/>
        <source>MX Boot Repair</source>
        <translation>Riparim Nisjeje MX</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="39"/>
        <source>MX Boot Repair is a utility that can be used to reinstall GRUB bootloader on the ESP (EFI System Partition), MBR (Master Boot Record) or root partition. It provides the option to reconstruct the GRUB configuration file and to back up and restore MBR or PBR (root).</source>
        <translation>Riparim Nisjeje MX është një mjet që mund të përdoret për të riinstaluar ngarkuesin GRUB të nisjeve në pjesën ESP (EFI System Partition), MBR (Master Boot Record) ose rrënjë. Ofron mundësinë të rindërtohet kartela e formësimit GRUB dhe të kopjeruhet dhe rikthehet në punë MBR-i ose PBR-i (rrënjë).</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="58"/>
        <source>What would you like to do?</source>
        <translation>Ç’do të donit të bëni?</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="79"/>
        <source>Backup MBR or PBR (legacy boot only)</source>
        <translation>Kopjeruaj MBR ose PBR (vetëm për nisje si dikur)</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="86"/>
        <source>Reinstall GRUB bootloader on ESP, MBR or PBR (root)</source>
        <translation>Riinstalo ngarkuesin GRUB të nisjeve në ESP, MBR ose PBR (rrënjë)</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="96"/>
        <source>Repair GRUB configuration file</source>
        <translation>Riparo kartelë formësimi GRUB-i</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="103"/>
        <source>Restore MBR or PBR from backup (legacy boot only)</source>
        <translation>Rikthe MBR ose PBR prej kopjeruajtjeje (vetëm për nisje si dikur)</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="136"/>
        <location filename="../mainwindow.cpp" line="563"/>
        <source>Select Boot Method</source>
        <translation>Përzgjidhni Metodë Nisjeje</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="154"/>
        <source>Master Boot Record</source>
        <translation>Regjistër i Përgjithshëm Nisjesh</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="157"/>
        <source>MBR</source>
        <translation>MBR</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="160"/>
        <location filename="../mainwindow.ui" line="430"/>
        <source>Alt+B</source>
        <translation>Alt+B</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="182"/>
        <source>Root (Partition Boot Record)</source>
        <translation>Rrënjë (Regjistër Nisjeje i Pjesës)</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="185"/>
        <location filename="../mainwindow.cpp" line="566"/>
        <source>root</source>
        <translation>rrënjë</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="236"/>
        <location filename="../mainwindow.cpp" line="565"/>
        <source>Install on:</source>
        <translation>Instaloje në:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="255"/>
        <location filename="../mainwindow.cpp" line="564"/>
        <source>Location:</source>
        <translation>Vend:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="277"/>
        <location filename="../mainwindow.cpp" line="574"/>
        <source>Select root location:</source>
        <translation>Përzgjidhni vendndodhje rrënje:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="290"/>
        <source>EFI System Partition</source>
        <translation>Pjesë EFI Sistemi</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="293"/>
        <source>ESP</source>
        <translation>ESP</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="420"/>
        <source>About this application</source>
        <translation>Mbi këtë aplikacion</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="423"/>
        <source>About...</source>
        <translation>Mbi…</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="472"/>
        <source>Display help </source>
        <translation>Shfaq ndihmën </translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="475"/>
        <source>Help</source>
        <translation>Ndihmë</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="482"/>
        <source>Alt+H</source>
        <translation>Alt+N</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="523"/>
        <source>Cancel any changes then quit</source>
        <translation>Anulo çfarëdo ndryshimi dhe dil</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="526"/>
        <source>Cancel</source>
        <translation>Anuloje</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="533"/>
        <source>Alt+N</source>
        <translation>Alt+A</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="552"/>
        <source>Apply any changes</source>
        <translation>Apliko çfarëdo ndryshimesh</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="555"/>
        <location filename="../mainwindow.cpp" line="77"/>
        <source>Apply</source>
        <translation>Aplikoji</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="93"/>
        <source>GRUB is being installed on %1 device.</source>
        <translation>Grub-i po instalohet në pajisjen %1.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="118"/>
        <location filename="../mainwindow.cpp" line="150"/>
        <location filename="../mainwindow.cpp" line="219"/>
        <location filename="../mainwindow.cpp" line="253"/>
        <location filename="../mainwindow.cpp" line="373"/>
        <location filename="../mainwindow.cpp" line="474"/>
        <location filename="../mainwindow.cpp" line="498"/>
        <location filename="../mainwindow.cpp" line="602"/>
        <location filename="../mainwindow.cpp" line="606"/>
        <location filename="../mainwindow.cpp" line="614"/>
        <location filename="../mainwindow.cpp" line="621"/>
        <location filename="../mainwindow.cpp" line="627"/>
        <location filename="../mainwindow.cpp" line="676"/>
        <source>Error</source>
        <translation>Gabim</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="118"/>
        <location filename="../mainwindow.cpp" line="219"/>
        <source>Could not create a temporary folder</source>
        <translation>S’u krijua një dosje e përkohshme</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="151"/>
        <location filename="../mainwindow.cpp" line="254"/>
        <source>Could not set up chroot environment.
Please double-check the selected location.</source>
        <translation>S’u ujdis dot mjedis chroot.
Ju lutemi, rikontrolloni vendndodhjen e përzgjedhur.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="216"/>
        <source>The GRUB configuration file (grub.cfg) is being rebuilt.</source>
        <translation>Kartela e formësimit GRUB (grub.cfg) po rikrijohet.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="271"/>
        <source>Backing up MBR or PBR from %1 device.</source>
        <translation>Po kopjeruhet MBR apo PBR që nga pajisja %1.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="345"/>
        <source>Warning</source>
        <translation>Kujdes</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="346"/>
        <source>You are going to write the content of </source>
        <translation>Do të shkruani lëndën e </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="346"/>
        <source> to </source>
        <translation> te </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="347"/>
        <source>

Are you sure?</source>
        <translation>

Jeni i sigurt?</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="353"/>
        <source>Restoring MBR/PBR from backup to %1 device.</source>
        <translation>Po rikthehet MBR/PBR prej kopjeruajtje te pajisja %1.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="374"/>
        <source>Could not find EFI system partition (ESP) on any system disks. Please create an ESP and try again.</source>
        <translation>S’u gjet dot pjesë sistemi EFIn (ESP) në ndonjë nga disqet. Ju lutemi, krijoni një ESP dhe riprovoni.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="420"/>
        <source>Select %1 location:</source>
        <translation>Përzgjidhni vendndodhje %1:</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="452"/>
        <source>Back</source>
        <translation>Mbrapsht</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="470"/>
        <source>Success</source>
        <translation>Sukses</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="470"/>
        <source>Process finished with success.&lt;p&gt;&lt;b&gt;Do you want to exit MX Boot Repair?&lt;/b&gt;</source>
        <translation>Procesi përfundoi me sukses.&lt;p&gt;&lt;b&gt;Doni të dilet nga Riparim Nisjesh MX?&lt;/b&gt;</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="474"/>
        <source>Process finished. Errors have occurred.</source>
        <translation>Procesi përfundoi. Ndodhën gabime.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="491"/>
        <source>Enter password to unlock %1 encrypted partition:</source>
        <translation>Jepni fjalëkalimin për të shkyçur pjesën e fshehtëzuar %1:</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="498"/>
        <source>Sorry, could not open %1 LUKS container</source>
        <translation>Na ndjeni, s’u hap dot kontejneri LUKS %1</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="573"/>
        <source>Select GRUB location</source>
        <translation>Përzgjidhni vendndodhje Grub-i</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="585"/>
        <source>Select Item to Back Up</source>
        <translation>Përzgjidhni Objektin për Kopjeruajtje</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="592"/>
        <source>Select Item to Restore</source>
        <translation>Përzgjidhni Objektin për Rikthim</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="602"/>
        <location filename="../mainwindow.cpp" line="627"/>
        <source>No location was selected.</source>
        <translation>S’u përzgjodh vendndodhje.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="607"/>
        <source>Please select the root partition of the system you want to fix.</source>
        <translation>Ju lutemi, përzgjidhni pjesën rrënjë të sistemit që doni të ndreqet.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="612"/>
        <source>Select backup file name</source>
        <translation>Përzgjidhni emër kartele kopjeruajtje</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="614"/>
        <location filename="../mainwindow.cpp" line="621"/>
        <source>No file was selected.</source>
        <translation>S’u përzgjodh kartelë.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="619"/>
        <source>Select MBR or PBR backup file</source>
        <translation>Përzgjidhni kartelë kopjeruajtje MBR-i ose PBR-i</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="644"/>
        <source>About %1</source>
        <translation>Mbi %1</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="646"/>
        <source>Version: </source>
        <translation>Version: </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="646"/>
        <source>Simple boot repair program for MX Linux</source>
        <translation>Program i thjeshtë riparimi nisjesh për MX Linux</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="648"/>
        <source>Copyright (c) MX Linux</source>
        <translation>Të drejta kopjimi (c) MX Linux</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="650"/>
        <source>%1 License</source>
        <translation>Licencë %1</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="662"/>
        <source>%1 Help</source>
        <translation>Ndihmë për %1</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="676"/>
        <source>Sorry, could not mount %1 partition</source>
        <translation>Na ndjeni, s’u çmontua dot pjesa %1</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../about.cpp" line="52"/>
        <source>License</source>
        <translation>Licencë</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="53"/>
        <location filename="../about.cpp" line="62"/>
        <source>Changelog</source>
        <translation>Regjistër ndryshimesh</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="54"/>
        <source>Cancel</source>
        <translation>Anuloje</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="72"/>
        <source>&amp;Close</source>
        <translation>&amp;Mbylle</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="51"/>
        <source>MX Boot Repair</source>
        <translation>Riparim Nisjeje MX</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="70"/>
        <source>Error</source>
        <translation>Gabim</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="71"/>
        <source>You seem to be logged in as root, please log out and log in as normal user to use this program.</source>
        <translation>Duket të jeni futur si rrënjë, ju lutemi, që të përdorni këtë program, dilni nga llogaria dhe hyni si përdorues i zakonshëm.</translation>
    </message>
</context>
</TS>

==> mx-bootrepair_23.4.tar.xz: mx-bootrepair-23.4/translations/mx-boot-repair_sq.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="sq">
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../mainwindow.ui" line="20"/>
        <source>MX Boot Repair</source>
        <translation>Riparim Nisjeje MX</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="39"/>
        <source>MX Boot Repair is a utility that can be used to reinstall GRUB bootloader on the ESP (EFI System Partition), MBR (Master Boot Record) or root partition. It provides the option to reconstruct the GRUB configuration file and to back up and restore MBR or PBR (root).</source>
        <translation>Riparim Nisjeje MX është një mjet që mund të përdoret për të riinstaluar ngarkuesin GRUB të nisjeve në pjesën ESP (EFI System Partition), MBR (Master Boot Record) ose rrënjë. Ofron mundësinë të rindërtohet kartela e formësimit GRUB dhe të kopjeruhet dhe rikthehet në punë MBR-i ose PBR-i (rrënjë).</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="58"/>
        <source>What would you like to do?</source>
        <translation>Ç’do të donit të bëni?</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="79"/>
        <source>Backup MBR or PBR (legacy boot only)</source>
        <translation>Kopjeruaj MBR ose PBR (vetëm për nisje si dikur)</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="86"/>
        <source>Reinstall GRUB bootloader on ESP, MBR or PBR (root)</source>
        <translation>Riinstalo ngarkuesin GRUB të nisjeve në ESP, MBR ose PBR (rrënjë)</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="96"/>
        <source>Repair GRUB configuration file</source>
        <translation>Riparo kartelë formësimi GRUB-i</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="103"/>
        <source>Restore MBR or PBR from backup (legacy boot only)</source>
        <translation>Rikthe MBR ose PBR prej kopjeruajtjeje (vetëm për nisje si dikur)</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="136"/>
        <location filename="../mainwindow.cpp" line="528"/>
        <source>Select Boot Method</source>
        <translation>Përzgjidhni Metodë Nisjeje</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="154"/>
        <source>Master Boot Record</source>
        <translation>Regjistër i Përgjithshëm Nisjesh</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="157"/>
        <source>MBR</source>
        <translation>MBR</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="160"/>
        <location filename="../mainwindow.ui" line="430"/>
        <source>Alt+B</source>
        <translation>Alt+B</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="182"/>
        <source>Root (Partition Boot Record)</source>
        <translation>Rrënjë (Regjistër Nisjeje i Pjesës)</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="185"/>
        <location filename="../mainwindow.cpp" line="531"/>
        <source>root</source>
        <translation>rrënjë</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="236"/>
        <location filename="../mainwindow.cpp" line="530"/>
        <source>Install on:</source>
        <translation>Instaloje në:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="255"/>
        <location filename="../mainwindow.cpp" line="529"/>
        <source>Location:</source>
        <translation>Vend:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="277"/>
        <location filename="../mainwindow.cpp" line="539"/>
        <source>Select root location:</source>
        <translation>Përzgjidhni vendndodhje rrënje:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="290"/>
        <source>EFI System Partition</source>
        <translation>Pjesë EFI Sistemi</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="293"/>
        <source>ESP</source>
        <translation>ESP</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="420"/>
        <source>About this application</source>
        <translation>Mbi këtë aplikacion</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="423"/>
        <source>About...</source>
        <translation>Mbi…</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="472"/>
        <source>Display help </source>
        <translation>Shfaq ndihmën </translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="475"/>
        <source>Help</source>
        <translation>Ndihmë</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="482"/>
        <source>Alt+H</source>
        <translation>Alt+N</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="523"/>
        <source>Cancel any changes then quit</source>
        <translation>Anulo çfarëdo ndryshimi dhe dil</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="526"/>
        <source>Cancel</source>
        <translation>Anuloje</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="533"/>
        <source>Alt+N</source>
        <translation>Alt+A</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="552"/>
        <source>Apply any changes</source>
        <translation>Apliko çfarëdo ndryshimesh</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="555"/>
        <location filename="../mainwindow.cpp" line="78"/>
        <source>Apply</source>
        <translation>Aplikoji</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="94"/>
        <source>GRUB is being installed on %1 device.</source>
        <translation>Grub-i po instalohet në pajisjen %1.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="132"/>
        <location filename="../mainwindow.cpp" line="218"/>
        <location filename="../mainwindow.cpp" line="338"/>
        <location filename="../mainwindow.cpp" line="439"/>
        <location filename="../mainwindow.cpp" line="463"/>
        <location filename="../mainwindow.cpp" line="567"/>
        <location filename="../mainwindow.cpp" line="571"/>
        <location filename="../mainwindow.cpp" line="579"/>
        <location filename="../mainwindow.cpp" line="586"/>
        <location filename="../mainwindow.cpp" line="592"/>
        <location filename="../mainwindow.cpp" line="642"/>
        <location filename="../mainwindow.cpp" line="653"/>
        <source>Error</source>
        <translation>Gabim</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="653"/>
        <source>Could not create a temporary folder</source>
        <translation>S’u krijua një dosje e përkohshme</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="133"/>
        <location filename="../mainwindow.cpp" line="219"/>
        <source>Could not set up chroot environment.
Please double-check the selected location.</source>
        <translation>S’u ujdis dot mjedis chroot.
Ju lutemi, rikontrolloni vendndodhjen e përzgjedhur.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="198"/>
        <source>The GRUB configuration file (grub.cfg) is being rebuilt.</source>
        <translation>Kartela e formësimit GRUB (grub.cfg) po rikrijohet.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="236"/>
        <source>Backing up MBR or PBR from %1 device.</source>
        <translation>Po kopjeruhet MBR apo PBR që nga pajisja %1.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="310"/>
        <source>Warning</source>
        <translation>Kujdes</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="311"/>
        <source>You are going to write the content of </source>
        <translation>Do të shkruani lëndën e </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="311"/>
        <source> to </source>
        <translation> te </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="312"/>
        <source>

Are you sure?</source>
        <translation>

Jeni i sigurt?</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="318"/>
        <source>Restoring MBR/PBR from backup to %1 device.</source>
        <translation>Po rikthehet MBR/PBR prej kopjeruajtje te pajisja %1.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="339"/>
        <source>Could not find EFI system partition (ESP) on any system disks. Please create an ESP and try again.</source>
        <translation>S’u gjet dot pjesë sistemi EFIn (ESP) në ndonjë nga disqet. Ju lutemi, krijoni një ESP dhe riprovoni.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="385"/>
        <source>Select %1 location:</source>
        <translation>Përzgjidhni vendndodhje %1:</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="417"/>
        <source>Back</source>
        <translation>Mbrapsht</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="435"/>
        <source>Success</source>
        <translation>Sukses</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="435"/>
        <source>Process finished with success.&lt;p&gt;&lt;b&gt;Do you want to exit MX Boot Repair?&lt;/b&gt;</source>
        <translation>Procesi përfundoi me sukses.&lt;p&gt;&lt;b&gt;Doni të dilet nga Riparim Nisjesh MX?&lt;/b&gt;</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="439"/>
        <source>Process finished. Errors have occurred.</source>
        <translation>Procesi përfundoi. Ndodhën gabime.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="456"/>
        <source>Enter password to unlock %1 encrypted partition:</source>
        <translation>Jepni fjalëkalimin për të shkyçur pjesën e fshehtëzuar %1:</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="463"/>
        <source>Sorry, could not open %1 LUKS container</source>
        <translation>Na ndjeni, s’u hap dot kontejneri LUKS %1</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="538"/>
        <source>Select GRUB location</source>
        <translation>Përzgjidhni vendndodhje Grub-i</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="550"/>
        <source>Select Item to Back Up</source>
        <translation>Përzgjidhni Objektin për Kopjeruajtje</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="557"/>
        <source>Select Item to Restore</source>
        <translation>Përzgjidhni Objektin për Rikthim</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="567"/>
        <location filename="../mainwindow.cpp" line="592"/>
        <source>No location was selected.</source>
        <translation>S’u përzgjodh vendndodhje.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="572"/>
        <source>Please select the root partition of the system you want to fix.</source>
        <translation>Ju lutemi, përzgjidhni pjesën rrënjë të sistemit që doni të ndreqet.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="577"/>
        <source>Select backup file name</source>
        <translation>Përzgjidhni emër kartele kopjeruajtje</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="579"/>
        <location filename="../mainwindow.cpp" line="586"/>
        <source>No file was selected.</source>
        <translation>S’u përzgjodh kartelë.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="584"/>
        <source>Select MBR or PBR backup file</source>
        <translation>Përzgjidhni kartelë kopjeruajtje MBR-i ose PBR-i</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="609"/>
        <source>About %1</source>
        <translation>Mbi %1</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="611"/>
        <source>Version: </source>
        <translation>Version: </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="612"/>
        <source>Simple boot repair program for MX Linux</source>
        <translation>Program i thjeshtë riparimi nisjesh për MX Linux</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="614"/>
        <source>Copyright (c) MX Linux</source>
        <translation>Të drejta kopjimi (c) MX Linux</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="616"/>
        <source>%1 License</source>
        <translation>Licencë %1</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="628"/>
        <source>%1 Help</source>
        <translation>Ndihmë për %1</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="642"/>
        <source>Sorry, could not mount %1 partition</source>
        <translation>Na ndjeni, s’u çmontua dot pjesa %1</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../about.cpp" line="52"/>
        <source>License</source>
        <translation>Licencë</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="53"/>
        <location filename="../about.cpp" line="62"/>
        <source>Changelog</source>
        <translation>Regjistër ndryshimesh</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="54"/>
        <source>Cancel</source>
        <translation>Anuloje</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="72"/>
        <source>&amp;Close</source>
        <translation>&amp;Mbylle</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="52"/>
        <source>MX Boot Repair</source>
        <translation>Riparim Nisjeje MX</translation>
    </message>
    <message>
        <source>Error</source>
        <translation type="vanished">Gabim</translation>
    </message>
    <message>
        <source>You seem to be logged in as root, please log out and log in as normal user to use this program.</source>
        <translation type="vanished">Duket të jeni futur si rrënjë, ju lutemi, që të përdorni këtë program, dilni nga llogaria dhe hyni si përdorues i zakonshëm.</translation>
    </message>
</context>
</TS>
